"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configureAuthorizationEndpoint = configureAuthorizationEndpoint;
const router_1 = require("../../shared/router");
const OpenId4VcSiopVerifierService_1 = require("../OpenId4VcSiopVerifierService");
function configureAuthorizationEndpoint(router, config) {
    router.post(config.endpointPath, async (request, response, next) => {
        const { agentContext, verifier } = (0, router_1.getRequestContext)(request);
        try {
            const openId4VcVerifierService = agentContext.dependencyManager.resolve(OpenId4VcSiopVerifierService_1.OpenId4VcSiopVerifierService);
            const isVpRequest = request.body.presentation_submission !== undefined;
            const authorizationResponse = request.body;
            if (isVpRequest)
                authorizationResponse.presentation_submission = JSON.parse(request.body.presentation_submission);
            const verificationSession = await openId4VcVerifierService.findVerificationSessionForAuthorizationResponse(agentContext, {
                authorizationResponse,
                verifierId: verifier.verifierId,
            });
            if (!verificationSession) {
                agentContext.config.logger.warn(`No verification session found for incoming authorization response for verifier ${verifier.verifierId}`);
                return (0, router_1.sendErrorResponse)(response, agentContext.config.logger, 404, 'invalid_request', null);
            }
            await openId4VcVerifierService.verifyAuthorizationResponse(agentContext, {
                authorizationResponse: request.body,
                verificationSession,
            });
            response.status(200).send();
        }
        catch (error) {
            (0, router_1.sendErrorResponse)(response, agentContext.config.logger, 500, 'invalid_request', error);
        }
        // NOTE: if we don't call next, the agentContext session handler will NOT be called
        next();
    });
}
//# sourceMappingURL=authorizationEndpoint.js.map